import { RankType } from '../../Rank';
import { getDivision, setRank, createImage, setGradeIcon } from '../../Util/Tool';
const { ccclass, property } = cc._decorator;

@ccclass
export default class RankItem extends cc.Component {

    @property(cc.Label)
    rank: cc.Label = null;

    @property(cc.Sprite)
    head: cc.Sprite = null;

    @property(cc.Label)
    nickName: cc.Label = null;

    @property(cc.Sprite)
    gradeIcon: cc.Sprite = null;

    @property(cc.Label)
    gradeName: cc.Label = null;

    index: number;
    onLoad() {
    }

    public updateData(data: any, index: any) {
        this.index = index;
        this.nickName.string = data.nickname;
        setRank(index + 1, this.rank);
        this.setInfo(data.type, data);
        createImage(data.avatarUrl, this.head);
    }

    public async setInfo(type: number, data: any) {
        if (!data || !data.KVDataList.length) return;
        const kvData = data.KVDataList.filter(v => v.key === data.dataKey)[0];
        const value = kvData ? kvData.value : null;
        switch (type) {
            case RankType.DIVISION:
                this.gradeIcon.node.active = true;
                const json = await getDivision(JSON.parse(value || {}).division, JSON.parse(value || {}).divisionLevel);

                const sprite = await setGradeIcon(json.division, json.level, 's');
                this.gradeIcon.spriteFrame = sprite;

                this.gradeName.string = `${json.name}·${JSON.parse(value || {}).divisionStar}星`;
                break;
            case RankType.ROOM_COUNT:
                this.gradeName.string = `对局数量：${value}`;
                this.gradeIcon.node.active = false;
                break;
            case RankType.WEALTH_COUPON:
                this.gradeName.string = `红包券数量：${value}`;
                this.gradeIcon.node.active = false;
                break;
        }
    }

    setImageSprite(node: cc.Node, url: string) {
        const comp = node.getComponent('ImageLoad');
        comp.setImageByUrl(url);
    }

}

export interface DivisionJson {
    level: number;
    name: string;
    division: number;
    star: number;
    scoremax: number;
    icon: string;
    scoremin: number;
    totalStar: number;
    items: any[];
}
